/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
/* gkr-ask-daemon.h: Global ask functionality

   Copyright (C) 2007 Stefan Walter

   The Gnome Keyring Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Gnome Keyring Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Gnome Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.

   Author: Stef Walter <stef@memberwebs.com>
*/

#ifndef _GKR_ASK_DAEMON_H_
#define _GKR_ASK_DAEMON_H_

#include <glib.h>

#include "gkr-ask-request.h"

void           gkr_ask_daemon_process     (GkrAskRequest* ask);

void           gkr_ask_daemon_set_display (const gchar* display);

const gchar*   gkr_ask_daemon_get_display (void);

typedef void (*GkrAskHook) (GkrAskRequest* ask, gpointer data);

void           gkr_ask_daemon_set_hook    (GkrAskHook hook, gpointer data);

#endif /* _GKR_ASK_DAEMON_H_ */
